unit VaxRingGroupList;

interface

uses
    System.SysUtils,
    System.Classes,
    Generics.Collections,
    VaxRingGroupAgentList;

type TVaxRingGroupDetails = class

   public

        m_objRingGroupAgentList : TVaxAgentList;
        m_sRingGroupName : string;
        m_nModeId : Integer;
        m_nModeType : Integer;

    public

        function AddAgent(sAgentName : string) : boolean;
        procedure RemoveAgent(sAgentName : string);

        function GetAllAgent(var objAgentList : TStringList) : boolean;
        function GetAgentCount() : Integer;

    public

    constructor Create();

end;

type TVaxRingGroupList = class

    m_objRingGroupList : TObjectDictionary<string, TVaxRingGroupDetails>;

 private

        function GenKey(sValue : string) : string;
        procedure DeleteRingGroupAll();

        function FindRingGroup(sRingGroup : string) : TVaxRingGroupDetails;

      public

        constructor Create();
        Destructor Destroy();

        procedure ResetOBJ();

        function AddRingGroup(sRingGroupName : string) : boolean;
        procedure RemoveRingGroup(sRingGroupName : string);

        function AddRingGroupMember(sRingGroupName : string; sAgentName : string) : boolean;
        procedure RemoveRingGroupAgent(sRingGroupName : string; sAgentName : string);

        function SetRingGroupProcessMode(sGroupName: String; nModeId: Integer; nModeType: Integer) : boolean;

        function GetRingGroupAgentList(sRingGroupName : string; var sListRingGroupAgent : TStringList) : boolean;
        function GetRingGroupDetails(sRingGroupName : string; var nModeId :Integer; var nModeType : Integer; var sListRingGroupAgent : TStringList) : boolean;

        function IsAgentExisted(sRingGroupName : string; sAgentName : string) : boolean;

        function GetRingGroupNameList(sListRingName: TStringList) : boolean;
        function GetRingGroupAgentCount(sRingGroupName : string) : Integer;
end;

implementation

      //////////////////////////////////////////////////////////////////////////////////////////
      //////////////////////////// Call PickUp Details //////////////////////////////////////////////

        constructor TVaxRingGroupDetails.Create();
        begin
              m_objRingGroupAgentList := TVaxAgentList.Create();
        end;

        function TVaxRingGroupDetails.GetAllAgent(var objAgentList : TStringList) : boolean;
        begin
              m_objRingGroupAgentList.GetAllAgentName(objAgentList);
        end;

        function TVaxRingGroupDetails.AddAgent(sAgentName : string) : boolean;
        begin
              Result :=  m_objRingGroupAgentList.AddAgent(sAgentName);
        end;

        procedure TVaxRingGroupDetails.RemoveAgent(sAgentName : string);
        begin
            m_objRingGroupAgentList.RemoveAgent(sAgentName);
        end;

        function TVaxRingGroupDetails.GetAgentCount() : Integer;
        begin
              Result := m_objRingGroupAgentList.GetAgentCount();
        end;

      //////////////////////////////////////////////////////////////////////////////////////////
      /////////////////////////////// Queue List ///////////////////////////////////////////////

        constructor TVaxRingGroupList.Create();
        begin
            m_objRingGroupList := TObjectDictionary<string, TVaxRingGroupDetails>.Create([doOwnsValues], 256);
        end;

        Destructor TVaxRingGroupList.Destroy();
        begin
            DeleteRingGroupAll();
            m_objRingGroupList.Free;
        end;

        function TVaxRingGroupList.GenKey(sValue : string) : string;
        begin
            Result := AnsiLowerCase(sValue);
        end;

        procedure TVaxRingGroupList.DeleteRingGroupAll();
        begin
            m_objRingGroupList.Clear;
        end;

        function TVaxRingGroupList.FindRingGroup(sRingGroup : string) : TVaxRingGroupDetails;
        var
            objRingGroupDetails : TVaxRingGroupDetails;
            bResult : Boolean;
        begin
            objRingGroupDetails := Nil;

            bResult := m_objRingGroupList.TryGetValue(sRingGroup, objRingGroupDetails);
            if(bResult = False) then
                Exit(nil);

            Result := objRingGroupDetails;
        end;

        procedure TVaxRingGroupList.ResetOBJ();
        begin
            DeleteRingGroupAll();
        end;

        function TVaxRingGroupList.AddRingGroup(sRingGroupName : string) : boolean;
        var
            sKey : string;
            objRingGroupDetails : TVaxRingGroupDetails;

        begin
            objRingGroupDetails :=  FindRingGroup(sRingGroupName);

            if(objRingGroupDetails <> Nil) then
                Exit(False);

            objRingGroupDetails := TVaxRingGroupDetails.Create();

            objRingGroupDetails.m_sRingGroupName := sRingGroupName;
            m_objRingGroupList.Add(sRingGroupName, objRingGroupDetails);

            Exit(True);

        end;

        procedure TVaxRingGroupList.RemoveRingGroup(sRingGroupName : string);
        var
            sKey : string;
            objRingGroupDetails : TVaxRingGroupDetails;

        begin
            objRingGroupDetails :=  FindRingGroup(sRingGroupName);

            if(objRingGroupDetails = Nil) then
               Exit();

             m_objRingGroupList.Remove(AnsiLowerCase(sRingGroupName));

        end;

        function TVaxRingGroupList.AddRingGroupMember(sRingGroupName : string; sAgentName : string) : boolean;
        var
            sKey : string;
            objRingGroupDetails : TVaxRingGroupDetails;

        begin
            objRingGroupDetails :=  FindRingGroup(sRingGroupName);

            if(objRingGroupDetails = Nil) then
               Exit(False);

            Result := objRingGroupDetails.AddAgent(sAgentName);
        end;

        procedure TVaxRingGroupList.RemoveRingGroupAgent(sRingGroupName : string; sAgentName : string);
         var
            sKey : string;
            objRingGroupDetails : TVaxRingGroupDetails;

         begin
            objRingGroupDetails :=  FindRingGroup(sRingGroupName);

            if(objRingGroupDetails = Nil) then
               Exit();

            objRingGroupDetails.RemoveAgent(sRingGroupName);

        end;

        function TVaxRingGroupList.SetRingGroupProcessMode(sGroupName: String; nModeId: Integer; nModeType: Integer) : boolean;
          var

            objRingGroupDetails : TVaxRingGroupDetails;

         begin

            objRingGroupDetails :=  FindRingGroup(sGroupName);

            if(objRingGroupDetails = Nil) then
               Exit(False);

              objRingGroupDetails.m_nModeId := nModeId;
              objRingGroupDetails.m_nModeType := nModeType;

              Exit(True);
        end;

        function TVaxRingGroupList.GetRingGroupAgentList(sRingGroupName : string; var sListRingGroupAgent : TStringList) : boolean;
        var
            sKey : string;
            objRingGroupDetails : TVaxRingGroupDetails;

         begin
            objRingGroupDetails :=  FindRingGroup(sRingGroupName);

            if(objRingGroupDetails = Nil) then
               Exit(False);


        end;


        function TVaxRingGroupList.GetRingGroupDetails(sRingGroupName : string; var nModeId :Integer; var nModeType : Integer; var sListRingGroupAgent : TStringList) : boolean;
        var
            sKey : string;
            objRingGroupDetails : TVaxRingGroupDetails;
         begin

            objRingGroupDetails :=  FindRingGroup(sRingGroupName);

            if(objRingGroupDetails = Nil) then
               Exit(False);

             nModeId := objRingGroupDetails.m_nModeId;
             nModeType := objRingGroupDetails.m_nModeType;

             Result := objRingGroupDetails.GetAllAgent(sListRingGroupAgent);
        end;

        function TVaxRingGroupList.IsAgentExisted(sRingGroupName : string; sAgentName : string) : boolean;
        var
            sKey : string;
            objRingGroupDetails : TVaxRingGroupDetails;

         begin
            objRingGroupDetails :=  FindRingGroup(sRingGroupName);

            if(objRingGroupDetails = Nil) then
               Exit(False);

            Result := True;

        end;

        function TVaxRingGroupList.GetRingGroupNameList(sListRingName: TStringList) : boolean;
        var
            sRingGroupName : string;
            objRingGroupDetails : TVaxRingGroupDetails;
         begin

         for objRingGroupDetails in m_objRingGroupList.Values do
             sListRingName.Add(objRingGroupDetails.m_sRingGroupName);

         Result := True;

        end;

        function TVaxRingGroupList.GetRingGroupAgentCount(sRingGroupName : string) : Integer;
        var
            sKey : string;
            objRingGroupDetails : TVaxRingGroupDetails;

         begin
            objRingGroupDetails :=  FindRingGroup(sRingGroupName);

            if(objRingGroupDetails = Nil) then
               Exit(-1);

        Result := objRingGroupDetails.GetAgentCount();

        end;

end.
