unit VaxTeleServerSIP;

interface

uses
    ErrorLogDlg,
    StatusLogDlg,
    SIPRecDlg,
    VaxDefine,
    Windows,
    psapi,
    System.SysUtils,
    System.Classes,
    Vcl.Dialogs,
    VaxServerExCOM;

type TVaxTeleServerSIP = class(TVaxServerExCOM)

    public

      m_objStatusLogDlg : TStatusLogForm;
      m_objErrorLogDlg : TErrorLogForm;
      m_objSIPRecDlg : TSIPRecForm;

      //////////////////////////////////////////////////////////////////////
      ///       Functions
      //////////////////////////////////////////////////////////////////////

      constructor Create();

      function GetAvailableMEM() : Integer;
      function GetUsageCPU() : Integer;

      function LoadMusicDialTone(sFileName : string) : Boolean;
      procedure UnLoadMusicDialTone();

      function LoadMusicCallPark(sFileName : string) : Boolean;
      procedure UnLoadMusicCallPark();

      procedure OnStatusLog(sStatus : string); override;
      procedure OnErrorLog(sError : string);override;

      procedure OnLineRegisterTryingREC(sLineName: string); override;
      procedure OnLineRegisterFailedREC(sLineName: string; nStatusCode: Integer; sReasonPhrase: string); override;
      procedure OnLineRegisterSuccessREC(sLineName: string); override;
      procedure OnLineUnRegisterTryingREC(sLineName: string); override;
      procedure OnLineUnRegisterFailedREC(sLineName: string; nStatusCode: Integer; sReasonPhrase: string); override;
      procedure OnLineUnRegisterSuccessREC(sLineName: string); override;

      procedure OnServerConnectingREC(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);  override;
      procedure OnServerConnectedREC(nSessionId: Integer; nChannelId: Integer);  override;
      procedure OnServerFailedREC(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);  override;
      procedure OnServerTimeoutREC(nSessionId: Integer; nChannelId: Integer);  override;
      procedure OnServerHungupREC(nSessionId: Integer; nChannelId: Integer);  override;

end;

implementation

var

    KernalDllHandle : THandle;
    SystemTimesPtr : Pointer;

      //////////////////////////////////////////////////////////////////////
      ///       Functions
      //////////////////////////////////////////////////////////////////////

      constructor TVaxTeleServerSIP.Create();
      var
        nError : Integer;
      begin
            inherited Create();

            KernalDllHandle := LoadLibraryW('Kernel32.dll');
            if KernalDllHandle <> 0 then
            begin
              SystemTimesPtr := GetProcAddress(KernalDllHandle, 'GetSystemTimes');
              if(SystemTimesPtr = Nil) then
              begin
                ShowMessage('GetProcAddress Failed.');
                FreeLibrary(KernalDllHandle);
              end;

            end;

      end;

      function TVaxTeleServerSIP.GetAvailableMEM() : Integer;
      var MemStatus: TMemoryStatusEx;
      begin
            FillChar(MemStatus, sizeof(MemStatus), 0);
            MemStatus.dwLength := sizeof(TMemoryStatusEx);

            Win32Check(GlobalMemoryStatusEx(MemStatus));
            Result := MemStatus.ullAvailPhys div ( 1024 * 1024);
      end;

      function TVaxTeleServerSIP.GetUsageCPU() : Integer;
      var
        time, createTime, exitTime : FILETIME;
        idleTimeProcess, kernelTimeProcess, userTimeProcess : FILETIME;
        sTime, sLastUpTime : Long;
        sLastCpu, sLastCpuProcess : Integer;

        idleTime, kernelTime, userTime : Long;
        usr, ker, idl, sys, cpu : Long;
      begin

            Result := 0;
      end;

      function TVaxTeleServerSIP.LoadMusicDialTone(sFileName : string) : Boolean;
      begin
        Result := inherited LoadMusicDialTone(sFileName);
      end;

      procedure TVaxTeleServerSIP.UnLoadMusicDialTone();
      begin
        inherited UnLoadMusicDialTone();
      end;

      function TVaxTeleServerSIP.LoadMusicCallPark(sFileName : string) : Boolean;
      begin
        Result := inherited LoadMusicCallPark(sFileName);
      end;

      procedure TVaxTeleServerSIP.UnLoadMusicCallPark();
      begin
        inherited UnLoadMusicCallPark();
      end;

      procedure TVaxTeleServerSIP.OnStatusLog(sStatus : string);
      begin
         m_objStatusLogDlg.OnStatusLog(sStatus);
      end;

      procedure TVaxTeleServerSIP.OnErrorLog(sError : string);
      begin
         m_objErrorLogDlg.OnErrorLog(sError);
      end;

     //////////////////////////////////////////////////////////////////////////////
     //////////////////////////////////////////////////////////////////////////////

     procedure TVaxTeleServerSIP.OnLineRegisterTryingREC(sLineName : string);
     begin
         m_objSIPRecDlg.OnLineRegisterTryingREC(sLineName);
     end;

     procedure TVaxTeleServerSIP.OnLineRegisterFailedREC(sLineName: string; nStatusCode: Integer; sReasonPhrase: string);
     begin
        m_objSIPRecDlg.OnLineRegisterFailedREC(sLineName, nStatusCode, sReasonPhrase);
     end;

     procedure TVaxTeleServerSIP.OnLineRegisterSuccessREC(sLineName: string);
     begin
        m_objSIPRecDlg.OnLineRegisterSuccessREC(sLineName);
     end;

     procedure TVaxTeleServerSIP.OnLineUnRegisterTryingREC(sLineName: string);
     begin
         m_objSIPRecDlg.OnLineUnRegisterTryingREC(sLineName);
     end;

     procedure TVaxTeleServerSIP.OnLineUnRegisterFailedREC(sLineName: string; nStatusCode: Integer; sReasonPhrase: string);
     begin
          m_objSIPRecDlg.OnLineUnRegisterFailedREC(sLineName, nStatusCode, sReasonPhrase);
     end;

     procedure TVaxTeleServerSIP.OnLineUnRegisterSuccessREC(sLineName: string);
     begin
         m_objSIPRecDlg.OnLineUnRegisterSuccessREC(sLineName);
     end;

     //////////////////////////////////////////////////////////////////////////////
     //////////////////////////////////////////////////////////////////////////////

     procedure TVaxTeleServerSIP.OnServerConnectingREC(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
     begin
        m_objSIPRecDlg.OnServerConnectingREC(nSessionId, nChannelId, nStatusCode, sReasonPhrase);
     end;

     procedure TVaxTeleServerSIP.OnServerConnectedREC(nSessionId: Integer; nChannelId: Integer);
     begin
        m_objSIPRecDlg.OnServerConnectedREC(nSessionId, nChannelId);
     end;

     procedure TVaxTeleServerSIP.OnServerFailedREC(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
     begin
        m_objSIPRecDlg.OnServerFailedREC(nSessionId, nChannelId, nStatusCode, sReasonPhrase);
     end;

      procedure TVaxTeleServerSIP.OnServerTimeoutREC(nSessionId: Integer; nChannelId: Integer);
      begin
        m_objSIPRecDlg.OnServerTimeoutREC(nSessionId, nChannelId);
      end;

      procedure TVaxTeleServerSIP.OnServerHungupREC(nSessionId: Integer; nChannelId: Integer);
      begin
        m_objSIPRecDlg.OnServerHungupREC(nSessionId, nChannelId);
      end;

      //////////////////////////////////////////////////////////////////////////////////
      //////////////////////////////////////////////////////////////////////////////////
end.

