﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Collections;


namespace ServerSIP 
{
    public partial class QueueForm : Form
    {
        private cVaxServerSIP m_objVaxTeleSIP;
                
        public QueueForm(ref cVaxServerSIP objVaxServer)
        {
            InitializeComponent();
            m_objVaxTeleSIP = objVaxServer;
        }

        private void QueueForm_Load(object sender, EventArgs e)
        {
            AddProcessMode();
        }

        private void BtnAddQueue_Click(object sender, EventArgs e)
        {
            if(comboQueueName.Text == "" || ComboQueueProcessMode.Text == "")
            {
                MessageBox.Show("Please fill all values.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return;
            }

            if(comboQueueName.FindStringExact(comboQueueName.Text) != -1)
            {
                if(MessageBox.Show("Queue already exists, do you want to continue?", "VaxTeleSIP", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation) == DialogResult.No)
                {
                    return;
                }
            }

            if(comboQueueName.Items.Contains(comboQueueName.Text))
                m_objVaxTeleSIP.RemoveQueue(comboQueueName.Text);

            if(!m_objVaxTeleSIP.AddQueue(comboQueueName.Text, EditQueueMusicFile.Text, EditQueueDialToneFile.Text))
            {
                MessageBox.Show("Queue could not be added/updated or Please start the server first.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return;
            }

            foreach (string sUserName in ListBoxLogin.Items)
            {
                m_objVaxTeleSIP.AddQueueAgent(comboQueueName.Text, sUserName);
            }

            if(!comboQueueName.Items.Contains(comboQueueName.Text))
                comboQueueName.Items.Add(comboQueueName.Text);

            int nProcessMode = GetProcessMode();
            if (nProcessMode == -1) return;

            int nProcessType = GetProcessType();
            if (nProcessType == -1) return;

            m_objVaxTeleSIP.SetQueueProcessMode(comboQueueName.Text, GetProcessMode(), GetProcessType());

            MessageBox.Show("Queue added/updated successfully.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
        }

        private void BtnRemoveQueue_Click(object sender, EventArgs e)
        {
            if(comboQueueName.Text == "" || (!comboQueueName.Items.Contains(comboQueueName.Text)))
                return;
                        
            int nIndex = comboQueueName.FindStringExact(comboQueueName.Text);
            if(nIndex == -1) return;

            m_objVaxTeleSIP.RemoveQueue(comboQueueName.Text);
            comboQueueName.Items.RemoveAt(nIndex);
            
            ClearDlgContent();

            if (comboQueueName.Items.Count > 0)
                comboQueueName.SelectedIndex = 0;

            ShowQueueDetails();

            MessageBox.Show("Queue removed successfully.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
        }

        private void BtnQueueClear_Click(object sender, EventArgs e)
        {
            comboQueueName.Text = "";
            ComboQueueProcessMode.Text = "";

            EditQueueMusicFile.Text = "";
            EditQueueDialToneFile.Text = "";

            comboQueueAgentName.Text = "";
            ListBoxLogin.Items.Clear();
        }

        private void BtnAddQueueAgent_Click(object sender, EventArgs e)
        {
            if(ListBoxLogin.FindStringExact(comboQueueAgentName.Text) != -1)
            {
                MessageBox.Show("Agent already exists.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return;
            }

            ListBoxLogin.Items.Add(comboQueueAgentName.Text);
        }

        private void BtnRemoveQueueAgent_Click(object sender, EventArgs e)
        {
            ListBoxLogin.Items.Remove(ListBoxLogin.SelectedItem);
        }

        private void BtnClearQueueAgent_Click(object sender, EventArgs e)
        {
            comboQueueAgentName.Text = "";
            ListBoxLogin.Items.Clear();
        }

        private void ClearDlgContent()
        {
            comboQueueName.Text = "";
            ComboQueueProcessMode.Text = "";
            ComboQueueProcessType.Text = "";
            
            ListBoxLogin.Items.Clear();
        }

        private int GetProcessMode()
        {
            if(ComboQueueProcessMode.SelectedIndex == -1)
            {
                MessageBox.Show("Please select a process mode.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return -1;
            }

            return ComboQueueProcessMode.SelectedIndex;
        }

        private void AddProcessMode()
        {
            ComboQueueProcessMode.Items.Clear();

            ComboQueueProcessMode.Items.Add(cDefine.USER_ALGO_HUNT_RANDOM);
            ComboQueueProcessMode.Items.Add(cDefine.USER_ALGO_FEWEST_ANSWERED);
            ComboQueueProcessMode.Items.Add(cDefine.USER_ALGO_LEAST_TALK_TIME);
            ComboQueueProcessMode.Items.Add(cDefine.USER_ALGO_LONGEST_WAITING);
            ComboQueueProcessMode.Items.Add(cDefine.USER_ALGO_PRIORITIZED_HUNT);
            ComboQueueProcessMode.Items.Add(cDefine.USER_ALGO_ROUND_ROBIN);
            ComboQueueProcessMode.Items.Add(cDefine.USER_ALGO_RING_ALL);

            ComboQueueProcessMode.SelectedIndex = 0;
        }

        private void AddProcessType()
        {
            ComboQueueProcessType.Items.Clear();

            ComboQueueProcessType.Items.Add(cDefine.ALGO_TYPE_FREE);
            ComboQueueProcessType.Items.Add(cDefine.ALGO_TYPE_ANY);

            ComboQueueProcessType.SelectedIndex = 0;
        }

        private int GetProcessType()
        {
            if(ComboQueueProcessType.SelectedIndex == -1)
            {
                MessageBox.Show("Please select a process type.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return -1;
            }

            return ComboQueueProcessType.SelectedIndex;
        }

        private void AddUsers()
        {
            comboQueueAgentName.Items.Clear();

            ArrayList objListUsers = new ArrayList();
            m_objVaxTeleSIP.GetUserAll(ref objListUsers);

            if(objListUsers.Count <= 0) return;

            for (int nIndex = 0; nIndex < objListUsers.Count; nIndex++)
                comboQueueAgentName.Items.Add(objListUsers[nIndex]);

            if(comboQueueAgentName.SelectedIndex == -1 && comboQueueAgentName.Items.Count > 0)
                comboQueueAgentName.SelectedIndex = 0;
        }

        private void AddQueues()
        {
            comboQueueName.Items.Clear();

            List<string> objListQueueName = new List<string>();
            m_objVaxTeleSIP.GetQueueNameAll(ref objListQueueName);

            if(objListQueueName.Count <= 0)
                return;

            foreach (string sQueueName in objListQueueName)
            {
                comboQueueName.Items.Add(sQueueName);
            }

            if(comboQueueName.Items.Count > 0)
                comboQueueName.SelectedIndex = 0;
        }

        public void OnSetActive()
        {
            AddProcessMode();
            AddProcessType();
            AddUsers();
            AddQueues();

            ShowQueueDetails();
        }

        public void OnCbnSelchangeComboQueue(object sender, EventArgs e)
        {
            ShowQueueDetails();
        }

        private void ShowQueueDetails()
        {
            string sQueueName = comboQueueName.Text;

            if (sQueueName.Length == 0)
                return;
            
            ListBoxLogin.Items.Clear();
            
            int nProcessMode = -1, nProcessType = -1;
            string sQueueMusicFile = "", sQueueDialToneFile = "";

            List<string> objListQueueAgent = new List<string>();

            if (!m_objVaxTeleSIP.GetQueueDetails(sQueueName, ref nProcessMode, ref nProcessType, ref objListQueueAgent, ref sQueueMusicFile, ref sQueueDialToneFile))
                return;

            ComboQueueProcessMode.SelectedIndex = nProcessMode;
            ComboQueueProcessType.SelectedIndex = nProcessType;

            EditQueueMusicFile.Text = sQueueMusicFile;
            EditQueueDialToneFile.Text = sQueueDialToneFile;
                       
           foreach (string sUserName in objListQueueAgent)
               ListBoxLogin.Items.Add(sUserName);
        }
      
    }
}
