unit VaxUser;

interface

uses

    System.Classes,
    VaxDefine,
    VaxServerExCOM;

type TVaxUser = class

    private

        m_sLogin, m_sPassword, m_sCodecList : string;
        m_sUserPrefix, m_sDialPrefix, m_sToPeerName : string;
        m_bBlocked, m_bIsRegistered : Boolean;
        m_nToPeerType : Integer;

    public

        procedure OnRegisterUser(sUserLogin: String; sDomain: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
        procedure OnRegisterUserSuccess(sUserLogin : string);
        procedure OnRegisterUserFailed(sUserLogin : string);

        procedure OnUnRegisterUser(sUserLogin : string);

    public

        constructor Create();

        procedure SetUserRegister(bRegister : boolean);

        function IsUserRegistered() : boolean;
        function IsUserBlocked() : boolean;

        function SetData(sLogin, sPassword, sCodecList : string; bBlocked : boolean; sUserPrefix, sDialPrefix : string; nToPeerType : Integer; sToPeerName : string) : boolean;
        function GetUserDetails(var sLogin : string; var sPassword, sCodecList : string; var bBlocked : boolean; var sUserPrefix, sDialPrefix : string; var nToPeerType : Integer; var sToPeerName : string) : boolean;

end;

implementation

        //////////////////////////////////////////////////////////////////////////
        /////////////       Events
        //////////////////////////////////////////////////////////////////////////

        procedure TVaxUser.OnRegisterUser(sUserLogin: String; sDomain: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
        begin

          If IsUserBlocked() then
          begin
            TVaxServerExCOM.mVaxExCOM.RejectRegister(nRegId, 404, TVaxDefine.NOT_FOUND);
            Exit;
          end;

          TVaxServerExCOM.mVaxExCOM.AuthRegister(nRegId);
          TVaxServerExCOM.mVaxExCOM.OnStatusLog(sUserLogin + ' ' + TVaxDefine.USER_REG_TRYING);

      end;

        procedure TVaxUser.OnRegisterUserSuccess(sUserLogin : string);
        begin
          TVaxServerExCOM.mVaxExCOM.OnStatusLog(sUserLogin + ' ' + TVaxDefine.USER_REG_SUCCESS);
          SetUserRegister(True);
        end;

        procedure TVaxUser.OnRegisterUserFailed(sUserLogin : string);
        begin
          TVaxServerExCOM.mVaxExCOM.OnStatusLog(sUserLogin + ' ' + TVaxDefine.USER_REG_FAILED);
        end;

        procedure TVaxUser.OnUnRegisterUser(sUserLogin : string);
        begin
          TVaxServerExCOM.mVaxExCOM.OnStatusLog(sUserLogin + ' logged off.');
          SetUserRegister(False);
        end;


        //////////////////////////////////////////////////////////////////////////
        /////////////       Functions
        //////////////////////////////////////////////////////////////////////////

        constructor TVaxUser.Create();
        begin

        end;

        procedure TVaxUser.SetUserRegister(bRegister : boolean);
        begin
            m_bIsRegistered := bRegister;
        end;

        function TVaxUser.IsUserRegistered() : boolean;
        begin
          Exit(m_bIsRegistered);
        end;

        function TVaxUser.IsUserBlocked() : boolean;
        begin
          Exit(m_bBlocked);
        end;

        function TVaxUser.SetData(sLogin, sPassword, sCodecList : string; bBlocked : boolean; sUserPrefix, sDialPrefix : string; nToPeerType : Integer; sToPeerName : string) : boolean;
        begin
              m_sLogin := sLogin;
              m_sPassword := sPassword;
              m_sCodecList := sCodecList;

              m_sUserPrefix := sUserPrefix;
              m_sDialPrefix := sDialPrefix;
              m_sToPeerName := sToPeerName;

              m_bBlocked := bBlocked;
              m_nToPeerType := nToPeerType;

              Exit(True);

        end;

        function TVaxUser.GetUserDetails(var sLogin : string; var sPassword, sCodecList : string; var bBlocked : boolean; var sUserPrefix, sDialPrefix : string; var nToPeerType : Integer; var sToPeerName : string) : boolean;
        begin
              sLogin := m_sLogin;
              sPassword := m_sPassword;
              sCodecList := m_sCodecList;

              sUserPrefix := m_sUserPrefix;
              sDialPrefix := m_sDialPrefix;
              sToPeerName := m_sToPeerName;

              bBlocked := m_bBlocked;
              nToPeerType := m_nToPeerType;

              Exit(True);

        end;
end.
